==> percona-server-5.7_5.7.40-43.orig.tar.gz: percona-server-5.7.40-43/extra/coredumper/src/CMakeFiles/coredumper.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/coredumper.c" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/CMakeFiles/coredumper.dir/coredumper.c.o"
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/thread_lister.c" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/CMakeFiles/coredumper.dir/thread_lister.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_WANT_LIB_EXT1__=1"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "extra/lz4/lz4-1.9.3"
  "extra/zlib/zlib-1.2.12"
  "include"
  "extra/rapidjson/include"
  "libbinlogevents/include"
  "libbinlogevents/export"
  "extra/coredumper/include"
  )
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/elfcore.cc" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/CMakeFiles/coredumper.dir/elfcore.cc.o"
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/linuxthreads.cc" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/CMakeFiles/coredumper.dir/linuxthreads.cc.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_WANT_LIB_EXT1__=1"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "extra/lz4/lz4-1.9.3"
  "extra/zlib/zlib-1.2.12"
  "include"
  "extra/rapidjson/include"
  "libbinlogevents/include"
  "libbinlogevents/export"
  "extra/coredumper/include"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")

==> percona-server-5.7_5.7.41-44.orig.tar.gz: percona-server-5.7.41-44/extra/coredumper/src/CMakeFiles/coredumper.dir/DependInfo.cmake <==
# The set of languages for which implicit dependencies are needed:
set(CMAKE_DEPENDS_LANGUAGES
  "C"
  "CXX"
  )
# The set of files for implicit dependencies of each language:
set(CMAKE_DEPENDS_CHECK_C
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/coredumper.c" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/CMakeFiles/coredumper.dir/coredumper.c.o"
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/thread_lister.c" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/CMakeFiles/coredumper.dir/thread_lister.c.o"
  )
set(CMAKE_C_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_C
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_WANT_LIB_EXT1__=1"
  )

# The include file search paths:
set(CMAKE_C_TARGET_INCLUDE_PATH
  "extra/lz4/lz4-1.9.4/lib"
  "extra/zlib/zlib-1.2.12"
  "include"
  "extra/rapidjson/include"
  "libbinlogevents/include"
  "libbinlogevents/export"
  "extra/coredumper/include"
  )
set(CMAKE_DEPENDS_CHECK_CXX
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/elfcore.cc" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/CMakeFiles/coredumper.dir/elfcore.cc.o"
  "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/linuxthreads.cc" "/mnt/jenkins/workspace/ps5.7-autobuild-RELEASE/test/percona-server/extra/coredumper/src/CMakeFiles/coredumper.dir/linuxthreads.cc.o"
  )
set(CMAKE_CXX_COMPILER_ID "GNU")

# Preprocessor definitions for this target.
set(CMAKE_TARGET_DEFINITIONS_CXX
  "HAVE_CONFIG_H"
  "HAVE_TLSv13"
  "LZ4_DISABLE_DEPRECATE_WARNINGS"
  "_FILE_OFFSET_BITS=64"
  "_GNU_SOURCE"
  "__STDC_WANT_LIB_EXT1__=1"
  )

# The include file search paths:
set(CMAKE_CXX_TARGET_INCLUDE_PATH
  "extra/lz4/lz4-1.9.4/lib"
  "extra/zlib/zlib-1.2.12"
  "include"
  "extra/rapidjson/include"
  "libbinlogevents/include"
  "libbinlogevents/export"
  "extra/coredumper/include"
  )

# Targets to which this target links.
set(CMAKE_TARGET_LINKED_INFO_FILES
  )

# Fortran module output directory.
set(CMAKE_Fortran_TARGET_MODULE_DIR "")
